"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.AllTimeStatsProcessors = exports.MonthlyStatsProcessors = void 0;
var data_1 = require("./data");
var info_1 = require("./info");
var commonProcessedStats = [
    function (stats) {
        stats.losses = stats.played - stats.victories;
    },
    function (stats) {
        if (stats.victories !== undefined)
            stats.win_percentage =
                stats.played === 0
                    ? "0%"
                    : "".concat(((stats.victories / stats.played) * 100).toFixed(2), "%");
    },
    function (stats) {
        Object.entries(stats).forEach(function (_a) {
            var key = _a[0], value = _a[1];
            if (Number.isNaN(value))
                delete stats[key];
        });
    }
];
var kdrProcessedStat = function (stats) {
    stats.kdr =
        stats.deaths === 0
            ? stats.kills
            : parseFloat((stats.kills / stats.deaths).toFixed(2));
};
exports.MonthlyStatsProcessors = (_a = {},
    _a[data_1.Game.BedWars] = __spreadArray([
        kdrProcessedStat,
        function (stats) {
            stats.fkdr =
                stats.deaths === 0
                    ? stats.final_kills
                    : parseFloat((stats.final_kills / stats.deaths).toFixed(2));
            stats.fkpr =
                stats.played === 0
                    ? stats.final_kills
                    : parseFloat((stats.final_kills / stats.played).toFixed(2));
        }
    ], commonProcessedStats, true),
    _a[data_1.Game.DeathRun] = commonProcessedStats,
    _a[data_1.Game.HideAndSeek] = commonProcessedStats,
    _a[data_1.Game.MurderMystery] = commonProcessedStats,
    _a[data_1.Game.SurvivalGames] = __spreadArray([kdrProcessedStat], commonProcessedStats, true),
    _a[data_1.Game.SkyWars] = __spreadArray([kdrProcessedStat], commonProcessedStats, true),
    _a[data_1.Game.JustBuild] = commonProcessedStats,
    _a[data_1.Game.GroundWars] = __spreadArray([kdrProcessedStat], commonProcessedStats, true),
    _a[data_1.Game.BlockDrop] = commonProcessedStats,
    _a[data_1.Game.CaptureTheFlag] = __spreadArray([kdrProcessedStat], commonProcessedStats, true),
    _a[data_1.Game.BlockParty] = commonProcessedStats,
    _a[data_1.Game.Bridge] = __spreadArray([
        kdrProcessedStat
    ], commonProcessedStats, true),
    _a[data_1.Game.Gravity] = commonProcessedStats,
    _a[data_1.Game.TreasureWars] = __spreadArray([
        kdrProcessedStat,
        function (stats) {
            stats.fkdr =
                stats.deaths === 0
                    ? stats.final_kills
                    : parseFloat((stats.final_kills / stats.deaths).toFixed(2));
            stats.fkpr =
                stats.played === 0
                    ? stats.final_kills
                    : parseFloat((stats.final_kills / stats.played).toFixed(2));
        }
    ], commonProcessedStats, true),
    _a);
exports.AllTimeStatsProcessors = Object.entries(exports.MonthlyStatsProcessors).reduce(function (acc, _a) {
    var _b;
    var game = _a[0], processors = _a[1];
    return (__assign(__assign({}, acc), (_b = {}, _b[game] = __spreadArray([
        function (stats) {
            var _a;
            var _b;
            stats.level = calculateLevel(game, stats.xp);
            if (info_1.GameXpInfo[game].max_prestige)
                (_a = (_b = stats).prestige) !== null && _a !== void 0 ? _a : (_b.prestige = 0);
        }
    ], processors, true), _b)));
}, {});
function calculateLevel(game, xp) {
    if (game === data_1.Game.Bridge) {
        if (!xp)
            return NaN;
        var lastXp = 0;
        var currentXp = 300;
        var increment_1 = 300;
        var additionalIncrement = 300;
        var i = 2;
        while (true) {
            if (xp === currentXp)
                return i;
            else if (xp < currentXp)
                return i + (xp - lastXp) / (currentXp - lastXp) - 1;
            additionalIncrement = Math.floor(additionalIncrement * 1.08);
            increment_1 += additionalIncrement;
            lastXp = currentXp;
            currentXp += increment_1;
            i++;
        }
    }
    var increment = info_1.GameXpInfo[game].increment / 2;
    var flattenLevel = info_1.GameXpInfo[game].increment_cap;
    var level = (-increment + Math.sqrt(Math.pow(increment, 2) - 4 * increment * -xp)) /
        (2 * increment) +
        1;
    if (flattenLevel && level > flattenLevel)
        level =
            flattenLevel +
                (xp -
                    (increment * Math.pow(flattenLevel - 1, 2) +
                        (flattenLevel - 1) * increment)) /
                    ((flattenLevel - 1) * increment * 2);
    return level;
}
//# sourceMappingURL=processors.js.map