import { AllTimeGameStats, Game, GameLeaderboard, GameStats, MonthlyGameStats, SeasonGame, SpecialGame, SpecialLeaderboardName } from "./games/data";
import { GameMetainfo } from "./games/info";
import { Player } from "./player/data";
import { GameMap } from "./map/data";
export declare function getHiveApiUrl(): string;
export declare function setHiveApiUrl(url: string): void;
export declare function getMonthlyStats(identifier: string, year?: number, month?: number, controller?: AbortController, init?: RequestInit): Promise<{
    bed: GameStats<Game.BedWars, MonthlyGameStats> | null;
    dr: GameStats<Game.DeathRun, MonthlyGameStats> | null;
    hide: GameStats<Game.HideAndSeek, MonthlyGameStats> | null;
    murder: GameStats<Game.MurderMystery, MonthlyGameStats> | null;
    sg: GameStats<Game.SurvivalGames, MonthlyGameStats> | null;
    sky: GameStats<Game.SkyWars, MonthlyGameStats> | null;
    build: GameStats<Game.JustBuild, MonthlyGameStats> | null;
    ground: GameStats<Game.GroundWars, MonthlyGameStats> | null;
    drop: GameStats<Game.BlockDrop, MonthlyGameStats> | null;
    ctf: GameStats<Game.CaptureTheFlag, MonthlyGameStats> | null;
    party: GameStats<Game.BlockParty, MonthlyGameStats> | null;
    bridge: GameStats<Game.Bridge, MonthlyGameStats> | null;
    grav: GameStats<Game.Gravity, MonthlyGameStats> | null;
    wars: GameStats<Game.TreasureWars, MonthlyGameStats> | null;
}>;
export declare function getGameMonthlyStats<G extends Game>(identifier: string, game: G, year?: number, month?: number, controller?: AbortController, init?: RequestInit): Promise<GameStats<G, MonthlyGameStats>>;
export declare function getGameSeasonStats<G extends SeasonGame>(identifier: string, game: G, season: number, controller?: AbortController, init?: RequestInit): Promise<GameStats<G, MonthlyGameStats>>;
export declare function getAllTimeStats(identifier: string, controller?: AbortController, init?: RequestInit): Promise<{
    bed: GameStats<Game.BedWars, AllTimeGameStats> | null;
    dr: GameStats<Game.DeathRun, AllTimeGameStats> | null;
    hide: GameStats<Game.HideAndSeek, AllTimeGameStats> | null;
    murder: GameStats<Game.MurderMystery, AllTimeGameStats> | null;
    sg: GameStats<Game.SurvivalGames, AllTimeGameStats> | null;
    sky: GameStats<Game.SkyWars, AllTimeGameStats> | null;
    build: GameStats<Game.JustBuild, AllTimeGameStats> | null;
    ground: GameStats<Game.GroundWars, AllTimeGameStats> | null;
    drop: GameStats<Game.BlockDrop, AllTimeGameStats> | null;
    ctf: GameStats<Game.CaptureTheFlag, AllTimeGameStats> | null;
    party: GameStats<Game.BlockParty, AllTimeGameStats> | null;
    bridge: GameStats<Game.Bridge, AllTimeGameStats> | null;
    grav: GameStats<Game.Gravity, AllTimeGameStats> | null;
    wars: GameStats<Game.TreasureWars, AllTimeGameStats> | null;
} & {
    main: Player | null;
}>;
export declare function getGameAllTimeStats<G extends Game>(identifier: string, game: G, controller?: AbortController, init?: RequestInit): Promise<GameStats<G, AllTimeGameStats>>;
export declare function getMainStats(identifier: string, controller?: AbortController, init?: RequestInit): Promise<Player>;
export declare function getMonthlyLeaderboard<G extends Game>(game: G, year?: number, month?: number, amount?: number, skip?: number, controller?: AbortController, init?: RequestInit): Promise<GameLeaderboard<G, MonthlyGameStats>>;
export declare function getSeasonLeaderboard<G extends SeasonGame>(game: G, season: number, amount?: number, skip?: number, controller?: AbortController, init?: RequestInit): Promise<GameLeaderboard<G, MonthlyGameStats>>;
export declare function getSpecialLeaderboard<G extends SpecialGame>(game: G, leaderboardName: SpecialLeaderboardName[G], amount?: number, skip?: number, controller?: AbortController, init?: RequestInit): Promise<GameLeaderboard<G, MonthlyGameStats>>;
export declare function getAllTimeLeaderboard<G extends Game>(game: G, controller?: AbortController, init?: RequestInit): Promise<GameLeaderboard<G, AllTimeGameStats>>;
export declare function getServerStats(controller?: AbortController, init?: RequestInit): Promise<{
    unique_players: {
        global: number;
        main: number;
    } & {
        [game in Game]: number;
    };
}>;
export declare function getGameMaps(game: Game, controller?: AbortController, init?: RequestInit): Promise<GameMap[]>;
export declare function getGameMetainfo(game: Game, controller?: AbortController, init?: RequestInit): Promise<GameMetainfo>;
export * from "./games/data";
export * from "./games/info";
export * from "./games/processors";
export * from "./map/data";
export * from "./player/data";
